package require Tk

set pi [expr { 2*asin(1) } ] 

set sun      0
set moon     1
set mercury  2
set venus    3
set mars     4
set jupiter  5
set saturn   6
set asc      7
set mh       8
set rahu     9
set ketu     10
set uranus   11
set neptune  12
set pluto    13
set fortune  14
set gulika   15
set mandi    16
set arudha   17 

set planets "$sun $moon $mercury $venus $mars $jupiter $saturn $asc $mh $rahu $ketu $uranus $neptune $pluto $fortune $gulika $mandi $arudha"

set aries       0
set taurus      1
set gemini      2
set cancer      3
set leo         4
set virgo       5
set libra       6
set scorpio     7
set sagittarius 8
set capricornus 9
set aquarius   10
set pisces     11

set signs   "$aries $taurus $gemini $cancer $leo $virgo $libra $scorpio $sagittarius $capricornus $aquarius $pisces"  

font create fontW  -family Wingdings 
font create fontAs -family Verdana
font create fontGu -family Verdana

set xDebug 250
set yDebug 0

proc debugOutput { c texte } {
 global xDebug yDebug
 $c create text $xDebug $yDebug -font Arial -text $texte -anchor "w"
 set yDebug [ expr {$yDebug + 20} ]
}

proc okAspect { pi pj } {

 global sun moon mercury venus mars jupiter saturn asc rahu ketu

 if { $pi == $pj } {
 	 return false
 	}

if { $pj == $mars || $pj == $jupiter || $pj == $saturn  } {
  if { $pi == $sun || $pi == $moon || $pi == $mercury || $pi == $venus || $pi == $mars || $pi == $jupiter || $pi == $saturn || $pi == $asc || $pi == $rahu || $pi == $ketu } {
   return true
  }
 }

		
 return false
}


# make an item (list) position
proc makeItemPosition { oX oY R nPlanet } {

 set itemPosition {}
 lappend itemPosition $oX
 lappend itemPosition $oY
 lappend itemPosition $R
 lappend itemPosition $nPlanet
 
 return $itemPosition
}

# add item position to a list of item positions
proc addItemPosition { listPositions itemPosition } {

 set varl [ lappend listPositions $itemPosition ]
 
 return $varl
 
}

# print on stdout the i position in listPositions
proc putsItemPosition { listPositions i } {

 set item  [ lindex $listPositions $i ]
 
 set oX       [ lindex $item 0 ]
 set oY       [ lindex $item 1 ]
 set R        [ lindex $item 2 ]
 set nPlanet  [ lindex $item 3 ]

 puts "oX=$oX"
 puts "oY=$oY"
 puts "R=$R"
 puts "nPlanet=$nPlanet" 
 
}

# get the item position (list) at i index 
proc getItemPosition { listPositions i } {

 set item  [ lindex $listPositions $i ]

 return $item
}

proc D2R { deg } {
 global pi
 return [ expr { $deg * $pi / 180.0 } ]
}

proc getColorSigns {} {

set colorSigns {}

 for { set i  0 } {$i < 12} {incr i} {
   
  if  { [ FillSignsOption ] == 1  } {
    lappend colorSigns [ GetSignColor $i -pseudoAlpha] 
  } else {
  
   lappend colorSigns [ GetBackgroundColor ] 
  }
  
 }

 return $colorSigns

}

################## Drawing primitives ######################

 proc  getPlanetFillColor { nPlanet nSign } {

 global jupiter saturn asc mh rahu ketu neptune gulika mandi arudha

  if { $nPlanet == $asc || $nPlanet == $mh || $nPlanet == $gulika || $nPlanet == $mandi || $nPlanet == $arudha } {
  	 return [GetPenColor]
  	}
  # no fill color for planets below
  if { $nPlanet == $jupiter ||  $nPlanet == $saturn  || $nPlanet == $rahu ||  $nPlanet == $ketu || $nPlanet == $neptune } {
  
  if { [PlanetIsRetro $nPlanet] == 1 } {
     set color [ GetPlanetColor $nPlanet $nSign -pen -retro] 
     return $color
   } else {
   	 set color [ GetPlanetColor $nPlanet $nSign -pen] 
   	 return $color
    }
    
   } else {
  
     if { [PlanetIsRetro $nPlanet] == 1 } {
         set color [ GetPlanetColor $nPlanet $nSign -brush -retro] 
         return $color
     } else {
   	  set color [ GetPlanetColor $nPlanet $nSign -brush] 
   	  return $color
   }
    
 	
 	}
  
 }  
 
 proc  getPlanetBorderColor { nPlanet nSign } {
 
 global asc mh gulika mandi arudha
 
  if { $nPlanet == $asc || $nPlanet == $mh || $nPlanet == $gulika || $nPlanet == $mandi || $nPlanet == $arudha } {
  	 return [GetPenColor]
  	}
    
  if { [PlanetIsRetro $nPlanet] == 1 } {
     set color [ GetPlanetColor $nPlanet $nSign -pen -retro] 
     return $color
   } else {
   	 set color [ GetPlanetColor $nPlanet $nSign -pen] 
     return $color
  }
  
 }
 
 proc  getPlanetPenSize { nPlanet } { 
  return 1
 }


proc drawCircle {c oX oY R pen_size outline_color fill_color} {
  set x1 [expr {$oX-$R}] 
  set y1 [expr {$oY-$R}] 
     
  set x2 [expr {$oX+$R}] 
  set y2 [expr {$oY+$R}] 
              
  $c create oval $x1 $y1 $x2 $y2 -outline $outline_color -fill $fill_color -width $pen_size
}
 
proc drawText {c x y fonte texte} {
  $c create text $x $y -font $fonte -text $texte
}
 
proc drawSign {c oX oY nSign fontW {color black} } {
  set aries "^"
  scan $aries "%c" val
  set val1 [ expr {$val + $nSign -1} ]
  set val2 [ format "%c" $val1 ]
  
  #font create fontW -family Wingdings -size [ expr { int(-2*$R) } ] -weight bold  
      
  $c create text [ expr {$oX}]  [ expr {$oY} ] -font $fontW -text $val2 -fill $color
 
}
 
proc drawSquare {c oX oY R outline_color fill_color} {
  set x1 [expr {$oX-$R}] 
  set y1 [expr {$oY-$R}] 
   
  set x2 [expr {$oX+$R}] 
  set y2 [expr {$oY+$R}] 
             
  $c create rectangle $x1 $y1 $x2 $y2 -outline $outline_color -fill $fill_color	

	}

proc drawLine {c x1 y1 x2 y2 pen_color pen_size  { dash_style ""} } {

 if { $dash_style == "" } {
   $c create line $x1 $y1 $x2 $y2 -fill $pen_color -width $pen_size	
  } else {
   $c create line $x1 $y1 $x2 $y2 -fill $pen_color -width $pen_size	-dash $dash_style
  }
}

# 1: top 2 bottom 3: left 4: right
proc drawCross {c x1 y1 x2 y2 x3 y3 x4 y4 pen_size pen_color { dash_style ""} }  {

 if { $dash_style == "" } {
   # top to bottom
   $c create line $x1 $y1 $x2 $y2 -fill $pen_color -width $pen_size	
   # left to right
   $c create line $x3 $y3 $x4 $y4 -fill $pen_color -width $pen_size	
  } else {
   # top to bottom
   $c create line $x1 $y1 $x2 $y2 -fill $pen_color -width $pen_size	 -dash $dash_style
   # left to right
   $c create line $x3 $y3 $x4 $y4 -fill $pen_color -width $pen_size	-dash $dash_style
  }

}

proc drawArrow {c x1 y1 x2 y2 pen_size pen_color  { dash_style ""} } {

 if { $dash_style == "" } {
   $c create line $x1 $y1 $x2 $y2 -fill $pen_color -width $pen_size	-arrow last
  } else {
   $c create line $x1 $y1 $x2 $y2 -fill $pen_color -width $pen_size	-dash $dash_style -arrow last
  }
}

###########################################################

proc drawSun {c oX oY R { pen_size 1 } {fill_color yellow} { outline_color  black} } {
 
 # draw the circle
 drawCircle $c  $oX $oY $R $pen_size $outline_color $fill_color
 
 # draw center point
 drawCircle $c  $oX $oY $pen_size $pen_size $outline_color $outline_color

}

proc drawMoon {c oX oY R { pen_size 1 } {fill_color white} { outline_color  black} } {
 
 set listXY {}
 
 for { set i -120.0 } { $i <= 120.0} { set i [expr {$i + 10.0}] } {
  set arads [ D2R $i ]
  set x [ expr { $oX + $R * cos($arads) } ]
  set y [ expr { $oY + $R * sin($arads) } ]
  
  lappend listXY $x $y
 }

 for { set i 60.0 } { $i >= -60.0} { set i [expr {$i - 10.0}] } {
  set arads [ D2R $i ]
  set x [ expr { $oX - $R + $R * cos($arads) } ]
  set y [ expr { $oY + $R * sin($arads) } ]
  
  lappend listXY $x $y
 }

$c create polygon $listXY  -outline $outline_color -fill $fill_color -width $pen_size

}

proc drawMercury {c oX oY R { pen_size 1 } {fill_color lightgrey} { outline_color  black} } {

 set unit [ expr {$R/6.0} ]
 
 # draw the cross      
 set X1  $oX                     
 set Y1  [ expr {$oY + 2.0*$unit} ]        
                              
 set X2  $oX                     
 set Y2  [ expr { $oY + $R} ]             
                              
 set X3  [ expr { $oX - 2.0*$unit } ]        
 set Y3  [ expr { $oY + 4.0*$unit } ]        
                              
 set X4  [ expr { $oX + 2.0*$unit } ]        
 set Y4  [ expr { $oY + 4.0*$unit } ]        
                              
 drawCross $c $X1 $Y1 $X2 $Y2 $X3 $Y3 $X4 $Y4 $pen_size $outline_color  
                             
 # Draw the upper arc 
 set X1  [ expr { $oX - 5.0*$unit  } ]
 set Y1  [ expr { $oY - 14.0*$unit } ]
 
 set X2  [ expr { $X1 + 10.0*$unit } ]
 set Y2  [ expr { $Y1 + 10.0*$unit } ]
 
 $c create arc $X1 $Y1 $X2 $Y2 -outline $outline_color -fill $fill_color -width $pen_size -start 210 -extent 120 -style arc

 # Draw the circle 

 set cX $oX
 set cY [ expr { $oY -$unit } ]
 set cR [ expr { $R/2.0} ]

 drawCircle $c $cX $cY $cR $pen_size $outline_color $fill_color 

}

proc drawVenus {c oX oY R { pen_size 1 } {fill_color green} { outline_color  black} } {

 set unit [ expr {$R/6.0} ]
 
 # draw the cross      
 set X1  $oX                     
 set Y1  [ expr {$oY + 2.0*$unit} ]        
                              
 set X2  $oX                     
 set Y2  [ expr { $oY + $R} ]             
                              
 set X3  [ expr { $oX - 2.0*$unit } ]        
 set Y3  [ expr { $oY + 4.0*$unit } ]        
                              
 set X4  [ expr { $oX + 2.0*$unit } ]        
 set Y4  [ expr { $oY + 4.0*$unit } ]        
                              
 drawCross $c $X1 $Y1 $X2 $Y2 $X3 $Y3 $X4 $Y4 $pen_size $outline_color  

 # Draw the circle 

 set cX $oX
 set cY [ expr { $oY -2.0 * $unit } ]
 set cR [ expr { 4.0 * $unit } ]

 drawCircle $c $cX $cY $cR $pen_size $outline_color $fill_color 

}

proc drawMars {c oX oY R { pen_size 1 } {fill_color red} { outline_color  black} } {

 set unit [ expr {$R/6.0} ]

 # Draw arrow
 set X1  [ expr { $oX + 2.1213*$unit } ]
 set Y1  [ expr { $oY - 2.1213*$unit } ]

 set X2  [ expr { $oX + $R } ]
 set Y2  [ expr { $oY - $R + $unit} ]

 drawArrow $c $X1 $Y1 $X2 $Y2 $pen_size $outline_color 

 # Draw the circle
 set cR [ expr { 3.0 * $unit } ]

 drawCircle $c $oX $oY $cR $pen_size $outline_color $fill_color 

}

proc drawJupiter {c oX oY R { pen_size 1 } { outline_color  navy} } {

 set unit [ expr { $R/6.0 } ]

 # Draw the cross
 set X1  [ expr  { $oX +3.0*$unit } ]
 set Y1  [ expr  { $oY +3.0*$unit } ]

 set X2  $X1
 set Y2  [ expr { $Y1 + 3.0*$unit } ]

 set X3  [ expr { $oX - 6.0*$unit } ]
 set Y3  [ expr { $oY + 4.0*$unit + $pen_size } ]

 set X4  [ expr { $X3 + 12.0*$unit } ]
 set Y4  $Y3

 drawCross $c $X1 $Y1 $X2 $Y2 $X3 $Y3 $X4 $Y4 $pen_size $outline_color


 # Draw arc
 set X1  [ expr { $oX - 16.0*$unit } ]
 set Y1  [ expr { $oY - 6.0*$unit } ]
 
 set X2  [ expr { $X1 + 20.0 * $unit } ]
 set Y2  [ expr { $Y1 + 10.0 * $unit } ]
   
 $c create arc $X1 $Y1 $X2 $Y2 -outline $outline_color -width $pen_size -start -90 -extent 180 -style arc

}

proc drawSaturn {c oX oY R { pen_size 1 } { outline_color  brown} } {

 set unit [ expr { $R/6.0 } ]
 
 # Draw the cross
 set X1  $oX
 set Y1  [ expr  { $oY - $R } ]

 set X2  $X1
 set Y2  [ expr { $Y1 + $R } ]

 set X3  [ expr { $oX - 2.0*$unit } ]
 set Y3  [ expr { $oY - 3.5*$unit } ]

 set X4  [ expr { $oX + 2.0*$unit } ]
 set Y4  $Y3

 drawCross $c $X1 $Y1 $X2 $Y2 $X3 $Y3 $X4 $Y4 $pen_size $outline_color


 # Draw arc
 set X1  [ expr { $oX - 6.0*$unit } ]
 set Y1  $oY 
 
 set X2  [ expr { $X1 + 12.0 * $unit } ]
 set Y2  [ expr { $Y1 +  6.0 * $unit } ]
   
 $c create arc $X1 $Y1 $X2 $Y2 -outline $outline_color -width $pen_size -start -90 -extent 180 -style arc

}

proc drawUranus {c oX oY R { pen_size 1 } {fill_color {dark olive green}} { outline_color  black} } {

# Draw the 2 arcs
 set delta [ expr { 4.8*$R/2.0} ]
 set X1  [ expr { $oX - $delta} ]
 set Y1  [ expr { $oY - $R } ]
 
 set X2  [ expr { $X1 +  2.0 * $R } ]
 set Y2  [ expr { $Y1 +  2.0 * $R } ]
   
 $c create arc $X1 $Y1 $X2 $Y2 -outline $outline_color -width $pen_size -start -60 -extent 120 -style arc

 set X1  [ expr { $oX + $delta -2.0*$R } ]
 set Y1  [ expr { $oY - $R } ]
 
 set X2  [ expr { $X1 +  2.0 * $R } ]
 set Y2  [ expr { $Y1 +  2.0 * $R } ]
   
 $c create arc $X1 $Y1 $X2 $Y2 -outline $outline_color -width $pen_size -start 120 -extent 120 -style arc

# Draw cross
 set X1  $oX
 set Y1  $oY 

 set X2  $X1
 set Y2  [ expr { $Y1 + $R/3.0 } ]

 set X3  [ expr { $oX - $delta + 2.0 * $R} ]
 set Y3  $oY

 set X4  [ expr { $oX + $delta - 2.0 * $R} ]
 set Y4  $oY

 drawCross $c $X1 $Y1 $X2 $Y2 $X3 $Y3 $X4 $Y4 $pen_size $outline_color

# Draw small circle

 set cX $oX
 set cY [ expr { $oY +2.0 * $R/3.0 } ]
 set cR [ expr { $R/3.0 } ]

 drawCircle $c $cX $cY $cR $pen_size $outline_color $fill_color 

}

proc drawNeptune {c oX oY R { pen_size 1 } {outline_color {deep sky blue}} } {

# Draw the cross
 set X1  $oX
 set Y1  [ expr { $oY -$R/2.0 } ]

 set X2  $oX
 set Y2  [ expr { $oY + $R } ]

 set X3  [ expr { $oX - $R/2.0 } ]
 set Y3  [ expr { $oY + $R/2.0 } ]

 set X4  [ expr { $oX + $R/2.0 } ]
 set Y4  [ expr { $oY + $R/2.0 } ]

 drawCross $c $X1 $Y1 $X2 $Y2 $X3 $Y3 $X4 $Y4 $pen_size $outline_color

# Draw the arc
 set delta [ expr { $R/6.0 } ]
 set X1  [ expr { $oX - $R + $delta } ]
 set Y1  [ expr { $oY  -2.0 * $R } ]
 
 set X2  [ expr { $X1 +  2.0 * $R -2.0*$delta } ]
 set Y2  [ expr { $Y1 +  2.0 * $R } ]
   
 $c create arc $X1 $Y1 $X2 $Y2 -outline $outline_color -width $pen_size -start 180 -extent 180 -style arc


}
 
 proc drawPluto {c oX oY R { pen_size 1 } {fill_color firebrick} { outline_color  black} } {

 set unit [ expr {  $R/6.0 } ]

 # Draw cross
 set X1  $oX
 set Y1  [ expr { $oY + $unit } ]

 set X2  $oX
 set Y2  [ expr { $oY + $R } ]

 set X3  [ expr { $oX - 2.0 * $unit } ]
 set Y3  [ expr { $oY + 4.0 * $unit } ]

 set X4  [ expr { $oX + 2.0 * $unit} ]
 set Y4  [ expr { $oY + 4.0*$unit }  ]

 drawCross $c $X1 $Y1 $X2 $Y2 $X3 $Y3 $X4 $Y4 $pen_size $outline_color

# Draw circle
 set cX $oX
 set cY [ expr { $oY -2.0 * $unit } ]
 set cR [ expr { 3.0 * $unit } ]

 drawCircle $c $cX $cY $cR $pen_size $outline_color $fill_color 

# Draw the arc
set X1  [ expr { $oX - 4.0*$unit} ]
set Y1  [ expr { $oY - 5.0*$unit} ]
 
set X2  [ expr { $X1 +  8.0 * $unit } ]
set Y2  [ expr { $Y1 +  6.0 * $unit } ]
   
$c create arc $X1 $Y1 $X2 $Y2 -outline $outline_color -width $pen_size -start 180 -extent 180 -style arc
}
 
proc drawRahu {c oX oY R { pen_size 1 } {outline_color {deep sky blue}} } {

set unit [ expr { $R/6.0 } ]

# Draw the arc
set X1  [ expr { $oX - 5.0*$unit} ]
set Y1  [ expr { $oY - 5.0*$unit} ]
 
set X2  [ expr { $X1 +  10.0 * $unit } ]
set Y2  [ expr { $Y1 +  10.0 * $unit } ]
   
$c create arc $X1 $Y1 $X2 $Y2 -outline $outline_color -width $pen_size -start -52.50 -extent 285.0 -style arc

# lines
set X1  [ expr { $oX - $R} ]
set Y1  [ expr { $oY + 4.0*$unit} ]
set X2  [ expr { $X1 + 3.0 * $unit } ]
set Y2  $Y1

drawLine $c $X1 $Y1 $X2 $Y2 $outline_color $pen_size

set X1  [ expr { $oX + 3.0 * $unit} ]
set Y1  [ expr { $oY + 4.0 * $unit} ]
set X2  [ expr { $X1 + 3.0 * $unit } ]
set Y2  $Y1

drawLine $c $X1 $Y1 $X2 $Y2 $outline_color $pen_size


} 
 
proc drawKetu {c oX oY R { pen_size 1 } {outline_color {deep sky blue}} } {

set unit [ expr { $R/6.0 } ]

# Draw the arc
set X1  [ expr { $oX - 5.0*$unit} ]
set Y1  [ expr { $oY - 5.0*$unit} ]
 
set X2  [ expr { $X1 +  10.0 * $unit } ]
set Y2  [ expr { $Y1 +  10.0 * $unit } ]
   
$c create arc $X1 $Y1 $X2 $Y2 -outline $outline_color -width $pen_size -start 128.0 -extent 283.0 -style arc

# lines
set X1  [ expr { $oX - $R} ]
set Y1  [ expr { $oY - 4.0*$unit} ]
set X2  [ expr { $X1 + 3.0 * $unit } ]
set Y2  $Y1

drawLine $c $X1 $Y1 $X2 $Y2 $outline_color $pen_size

set X1  [ expr { $oX + 3.0 * $unit} ]
set Y1  [ expr { $oY - 4.0 * $unit} ]
set X2  [ expr { $X1 + 3.0 * $unit } ]
set Y2  $Y1

drawLine $c $X1 $Y1 $X2 $Y2 $outline_color $pen_size


} 

proc drawFortune {c oX oY R { pen_size 1 } {fill_color {deep pink}} { outline_color  black} } {

# Draw circle 
 drawCircle $c $oX $oY $R $pen_size $outline_color $fill_color 

# Draw cross
set X1  $oX
set Y1  [ expr { $oY - $R } ]

set X2  $oX
set Y2  [ expr { $oY + $R } ]

set X3  [ expr { $oX - $R } ]
set Y3  $oY

set X4  [ expr { $oX + $R} ]
set Y4  $oY

drawCross $c $X1 $Y1 $X2 $Y2 $X3 $Y3 $X4 $Y4 $pen_size $outline_color

}

proc drawAs {c oX oY R { pen_size 1 } { outline_color  black} } {

#font create fontAs -family Verdana -size [ expr { int( -2 * $R ) } ] 
font configure fontAs -size [ expr { int( -2*$R ) } ] 
$c create text $oX  $oY -font fontAs -text "As" -fill $outline_color

}

proc drawGulika {c oX oY R { pen_size 1 } { outline_color  black} } {

#font create fontAs -family Verdana -size [ expr { int( -2 * $R ) } ] 
font configure fontGu -size [ expr { int( - $R ) } ] 
$c create text $oX  $oY -font fontGu -text "Gu" -fill $outline_color

}

proc drawArudha {c oX oY R { pen_size 1 } { outline_color  black} } {

#font create fontAs -family Verdana -size [ expr { int( -2 * $R ) } ] 
font configure fontGu -size [ expr { int( - $R ) } ] 
$c create text $oX  $oY -font fontGu -text "Ar" -fill $outline_color
}

proc drawMandi {c oX oY R { pen_size 1 } { outline_color  black} } {

#font create fontAs -family Verdana -size [ expr { int( -2 * $R ) } ] 
font configure fontGu -size [ expr { int( - $R ) } ] 
$c create text $oX  $oY -font fontGu -text "Ma" -fill $outline_color
}


proc drawPlanet {c oX oY R nPlanet fill_color listPoints pen_size outline_color} { 

global sun moon mercury venus mars jupiter saturn uranus neptune pluto rahu ketu asc fortune gulika mandi arudha
  
  upvar $listPoints listPoints_loc
 
  set varPoint {}
  lappend varPoint $nPlanet
  lappend varPoint $oX
  lappend varPoint $oY
  lappend varPoint $R
  lappend listPoints_loc $varPoint
   
   
   
 
  	if { $nPlanet == $sun } {
  		 drawSun $c $oX $oY $R $pen_size $fill_color $outline_color 
  	} elseif {  $nPlanet == $moon } {
       drawMoon $c $oX $oY $R $pen_size $fill_color $outline_color      	
    } elseif {  $nPlanet == $mercury } {
    	 drawMercury $c $oX $oY $R $pen_size $fill_color $outline_color
    } elseif {  $nPlanet == $venus } {
    	 drawVenus $c $oX $oY $R $pen_size $fill_color $outline_color
    } elseif {  $nPlanet == $mars } {
    	 drawMars $c $oX $oY $R $pen_size $fill_color $outline_color
    } elseif {  $nPlanet == $jupiter } {
    	 drawJupiter $c $oX $oY $R $pen_size $outline_color
    } elseif {  $nPlanet == $saturn } {
    	 drawSaturn $c $oX $oY $R $pen_size $outline_color
    } elseif {  $nPlanet == $uranus } {
    	 drawUranus $c $oX $oY $R $pen_size $fill_color $outline_color
    } elseif {  $nPlanet == $neptune } {
 	     drawNeptune $c $oX $oY $R $pen_size $outline_color
    } elseif {  $nPlanet == $pluto } {
    	 drawPluto $c $oX $oY $R $pen_size $fill_color $outline_color
    } elseif {  $nPlanet == $rahu } {
    	 drawRahu $c $oX $oY $R $pen_size $outline_color
    } elseif {  $nPlanet == $ketu } {
    	 drawKetu $c $oX $oY $R $pen_size $outline_color
    } elseif {  $nPlanet == $asc } {
       drawAs $c $oX $oY $R $pen_size $outline_color
    } elseif {  $nPlanet == $fortune } {
       drawFortune $c $oX $oY $R $pen_size $fill_color $outline_color
    } elseif {  $nPlanet == $gulika } {
       drawGulika $c $oX $oY $R $pen_size $outline_color
    } elseif {  $nPlanet == $mandi} {
       drawMandi $c $oX $oY $R $pen_size $outline_color
    } elseif {  $nPlanet == $arudha } {
       drawArudha $c $oX $oY $R $pen_size $outline_color
    } 
    # else { debugOutput $c "Bad planet number $nPlanet" }


}

proc drawListPlanets {c X1 Y1 X2 Y2 listPlanet nSign listPoints } {

 upvar $listPoints listPoints_loc
 
 set nElem [ llength $listPlanet ]
 if { $nElem == 1 } {
  set deltaX [ expr { ($X2 - $X1)/6.0 } ]
  set deltaY [ expr { ($Y2 - $Y1)/6.0 } ]
  
  set oX  [ expr { $X1 + 4.0 * $deltaX } ]
  set oY  [ expr { $Y1 + 4.0 * $deltaY } ]
  set R   [ expr { min ( $deltaX, $deltaY ) } ]
  
  set nPlanet [ lindex $listPlanet 0 ]
  
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]
    
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color 
 } elseif { $nElem == 2 } {
  set nPlanet [ lindex $listPlanet 0 ]
  set deltaX [ expr { ($X2 - $X1)/6.0 } ]
  set deltaY [ expr { ($Y2 - $Y1)/6.0 } ]
  set R   [ expr { min ( $deltaX, $deltaY ) } ]
  
  set oX  [ expr { $X1 + 2.0 * $deltaX } ]
  set oY  [ expr { $Y1 + 4.0 * $deltaY } ]
  set fill_color    [ getPlanetFillColor $nPlanet $nSign  ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]
 
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  set nPlanet [ lindex $listPlanet 1 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 4.0 * $deltaX } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
  } elseif { $nElem == 3 } {
  set deltaX [ expr { ($X2 - $X1)/6.0 } ]
  set deltaY [ expr { ($Y2 - $Y1)/6.0 } ]
  set R   [ expr { min ( $deltaX, $deltaY ) } ]
  
  set oX  [ expr { $X1 + 4.0 * $deltaX } ]
  set oY  [ expr { $Y1 + 2.0 * $deltaY } ]
  set nPlanet [ lindex $listPlanet 0 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]
 
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  set nPlanet [ lindex $listPlanet 1 ]
  set fill_color    [ getPlanetFillColor $nPlanet $nSign  ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 2.0 * $deltaX } ]
  set oY  [ expr { $Y1 + 4.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  set nPlanet [ lindex $listPlanet 2 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign  ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 4.0 * $deltaX } ]
  set oY  [ expr { $Y1 + 4.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
  
  } elseif { $nElem == 4 } {
  set deltaX [ expr { ($X2 - $X1)/6.0 } ]
  set deltaY [ expr { ($Y2 - $Y1)/6.0 } ]
  set R   [ expr { min ( $deltaX, $deltaY ) } ]
  
  set oX  [ expr { $X1 + 4.0 * $deltaX } ]
  set oY  [ expr { $Y1 + 2.0 * $deltaY } ]
  set nPlanet [ lindex $listPlanet 0 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]
 
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  set nPlanet [ lindex $listPlanet 1 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 1.0 * $deltaX } ]
  set oY  [ expr { $Y1 + 5.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  set nPlanet [ lindex $listPlanet 2 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 3.0 * $deltaX } ]
  set oY  [ expr { $Y1 + 5.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
  
  set nPlanet [ lindex $listPlanet 3 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 5.0 * $deltaX } ]
  set oY  [ expr { $Y1 + 5.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
  
 } elseif { $nElem == 5 } {
  set deltaX [ expr { ($X2 - $X1)/12.0 } ]
  set deltaY [ expr { ($Y2 - $Y1)/12.0 } ]
  set R   [ expr { 1.5 * min ( $deltaX, $deltaY ) } ]
  
  set oX  [ expr { $X1 + 7.5 * $deltaX } ]
  set oY  [ expr { $Y1 + 3.5 * $deltaY } ]
  set nPlanet [ lindex $listPlanet 0 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]
  #1
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  set nPlanet [ lindex $listPlanet 1 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 10.5 * $deltaX } ]
  set oY  [ expr { $Y1 +  3.5 * $deltaY } ]
  #2
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  set nPlanet [ lindex $listPlanet 2 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 2.5 * $deltaX } ]
  set oY  [ expr { $Y1 + 9.5 * $deltaY } ]
  #3
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
  
  set nPlanet [ lindex $listPlanet 3 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 6.0 * $deltaX } ]
  set oY  [ expr { $Y1 + 9.5 * $deltaY } ]
  #4
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  set nPlanet [ lindex $listPlanet 4 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 9.5 * $deltaX } ]
  set oY  [ expr { $Y1 + 9.5 * $deltaY } ]
  #5
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

 } elseif { $nElem == 6 } {
  set deltaX [ expr { ($X2 - $X1)/12.0 } ]
  set deltaY [ expr { ($Y2 - $Y1)/12.0 } ]
  set R   [ expr { 1.5 * min ( $deltaX, $deltaY ) } ]
  #1
  set oX  [ expr { $X1 + 7.5 * $deltaX } ]
  set oY  [ expr { $Y1 + 3.5 * $deltaY } ]
  set nPlanet [ lindex $listPlanet 0 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  #2
  set nPlanet [ lindex $listPlanet 1 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 10.5 * $deltaX } ]
  set oY  [ expr { $Y1 +  3.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  #3
  set nPlanet [ lindex $listPlanet 2 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 1.5 * $deltaX } ]
  set oY  [ expr { $Y1 + 9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
  
  #4
  set nPlanet [ lindex $listPlanet 3 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 4.5 * $deltaX } ]
  set oY  [ expr { $Y1 + 9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #5
  set nPlanet [ lindex $listPlanet 4 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 7.5 * $deltaX } ]
  set oY  [ expr { $Y1 + 9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
  
  #6
  set nPlanet [ lindex $listPlanet 5 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 10.5 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

 } elseif { $nElem == 7 } {
  set deltaX [ expr { ($X2 - $X1)/12.0 } ]
  set deltaY [ expr { ($Y2 - $Y1)/12.0 } ]
  set R   [ expr { 1.0 * min ( $deltaX, $deltaY ) } ]
  #1
  set oX  [ expr { $X1 + 7.0 * $deltaX } ]
  set oY  [ expr { $Y1 + 3.0 * $deltaY } ]
  set nPlanet [ lindex $listPlanet 0 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  #2
  set nPlanet [ lindex $listPlanet 1 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  9.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  3.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  #3
  set nPlanet [ lindex $listPlanet 2 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 11.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  3.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
  
  #4
  set nPlanet [ lindex $listPlanet 3 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 1.5 * $deltaX } ]
  set oY  [ expr { $Y1 + 9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #5
  set nPlanet [ lindex $listPlanet 4 ]
  set fill_color    [ getPlanetFillColor $nPlanet $nSign  ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 4.5 * $deltaX } ]
  set oY  [ expr { $Y1 + 9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
  
  #6
  set nPlanet [ lindex $listPlanet 5 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  7.5 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #7
  set nPlanet [ lindex $listPlanet 6 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 10.5 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

 } elseif { $nElem == 8 } {
  set deltaX [ expr { ($X2 - $X1)/12.0 } ]
  set deltaY [ expr { ($Y2 - $Y1)/12.0 } ]
  set R   [ expr { 1.0 * min ( $deltaX, $deltaY ) } ]
  #1
  set oX  [ expr { $X1 + 7.0 * $deltaX } ]
  set oY  [ expr { $Y1 + 3.0 * $deltaY } ]
  set nPlanet [ lindex $listPlanet 0 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  #2
  set nPlanet [ lindex $listPlanet 1 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  9.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  3.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  #3
  set nPlanet [ lindex $listPlanet 2 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 11.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  3.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
  
  #4
  set R   [ expr { 1.5 * min ( $deltaX, $deltaY ) } ]
  set nPlanet [ lindex $listPlanet 3 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 8.5 * $deltaX } ]
  set oY  [ expr { $Y1 + 6.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #5
  set nPlanet [ lindex $listPlanet 4 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 1.5 * $deltaX } ]
  set oY  [ expr { $Y1 + 9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc  $pen_size $outline_color
  
  #6
  set nPlanet [ lindex $listPlanet 5 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  4.5 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #7
  set nPlanet [ lindex $listPlanet 6 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  7.5 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc  $pen_size $outline_color

  #8
  set nPlanet [ lindex $listPlanet 7 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 10.5 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

 } elseif { $nElem == 9 } {
  set deltaX [ expr { ($X2 - $X1)/12.0 } ]
  set deltaY [ expr { ($Y2 - $Y1)/12.0 } ]
  set R   [ expr { 1.0 * min ( $deltaX, $deltaY ) } ]
  #1
  set oX  [ expr { $X1 + 7.0 * $deltaX } ]
  set oY  [ expr { $Y1 + 3.0 * $deltaY } ]
  set nPlanet [ lindex $listPlanet 0 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  #2
  set nPlanet [ lindex $listPlanet 1 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  9.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  3.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  #3
  set nPlanet [ lindex $listPlanet 2 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 11.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  3.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
  
  #4
  set R   [ expr { 1.5 * min ( $deltaX, $deltaY ) } ]
  set nPlanet [ lindex $listPlanet 3 ]
  set fill_color    [ getPlanetFillColor $nPlanet $nSign  ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 7.5 * $deltaX } ]
  set oY  [ expr { $Y1 + 6.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #5
  set nPlanet [ lindex $listPlanet 4 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 10.5 * $deltaX } ]
  set oY  [ expr { $Y1 +  6.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
  
  #6
  set nPlanet [ lindex $listPlanet 5 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  1.5 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #7
  set nPlanet [ lindex $listPlanet 6 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  4.5 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc  $pen_size $outline_color

  #8
  set nPlanet [ lindex $listPlanet 7 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  7.5 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc  $pen_size $outline_color

  #9
  set nPlanet [ lindex $listPlanet 8 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 10.5 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

} elseif { $nElem == 10 } {
  set deltaX [ expr { ($X2 - $X1)/12.0 } ]
  set deltaY [ expr { ($Y2 - $Y1)/12.0 } ]
  set R   [ expr { 1.0 * min ( $deltaX, $deltaY ) } ]
  #1
  set oX  [ expr { $X1 + 7.0 * $deltaX } ]
  set oY  [ expr { $Y1 + 3.0 * $deltaY } ]
  set nPlanet [ lindex $listPlanet 0 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  #2
  set nPlanet [ lindex $listPlanet 1 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  9.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  3.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  #3
  set nPlanet [ lindex $listPlanet 2 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 11.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  3.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
  
  #4
  set R   [ expr { 1.5 * min ( $deltaX, $deltaY ) } ]
  set nPlanet [ lindex $listPlanet 3 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 7.5 * $deltaX } ]
  set oY  [ expr { $Y1 + 6.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #5
  set nPlanet [ lindex $listPlanet 4 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 10.5 * $deltaX } ]
  set oY  [ expr { $Y1 +  6.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color  listPoints_loc $pen_size $outline_color
  
  #6
  set nPlanet [ lindex $listPlanet 5 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set deltaX [ expr { ($X2 - $X1)/10.0 } ]
  set deltaY [ expr { ($Y2 - $Y1)/12.0 } ]
  set R   [ expr { 1.0 * min ( $deltaX, $deltaY ) } ]
  
  set oX  [ expr { $X1 +  1.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #7
  set nPlanet [ lindex $listPlanet 6 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  3.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #8
  set nPlanet [ lindex $listPlanet 7 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  5.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #9
  set nPlanet [ lindex $listPlanet 8 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  7.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #10
  set nPlanet [ lindex $listPlanet 9 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  9.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

} elseif { $nElem == 11 } {
  set deltaX [ expr { ($X2 - $X1)/12.0 } ]
  set deltaY [ expr { ($Y2 - $Y1)/12.0 } ]
  set R   [ expr { 1.0 * min ( $deltaX, $deltaY ) } ]
  #1
  set oX  [ expr { $X1 + 7.0 * $deltaX } ]
  set oY  [ expr { $Y1 + 3.0 * $deltaY } ]
  set nPlanet [ lindex $listPlanet 0 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  #2
  set nPlanet [ lindex $listPlanet 1 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  9.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  3.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  #3
  set nPlanet [ lindex $listPlanet 2 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 11.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  3.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
  
  #4
  set nPlanet [ lindex $listPlanet 3 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 7.0 * $deltaX } ]
  set oY  [ expr { $Y1 + 6.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #5
  set nPlanet [ lindex $listPlanet 4 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  9.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  6.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
  
  #6
  set nPlanet [ lindex $listPlanet 5 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]
  
  set oX  [ expr { $X1 +  11.0 * $deltaX } ]
  set oY  [ expr { $Y1 +   6.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #7
  set nPlanet [ lindex $listPlanet 6 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set deltaX [ expr { ($X2 - $X1)/10.0 } ]
  set deltaY [ expr { ($Y2 - $Y1)/12.0 } ]
  set R   [ expr { 1.0 * min ( $deltaX, $deltaY ) } ]

  set oX  [ expr { $X1 +  1.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #8
  set nPlanet [ lindex $listPlanet 7 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  3.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #9
  set nPlanet [ lindex $listPlanet 8 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  5.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #10
  set nPlanet [ lindex $listPlanet 9 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  7.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #11
  set nPlanet [ lindex $listPlanet 10 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  9.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.5 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

} elseif { $nElem == 12 } {
  set deltaX [ expr { ($X2 - $X1)/12.0 } ]
  set deltaY [ expr { ($Y2 - $Y1)/12.0 } ]
  set R   [ expr { min ( $deltaX, $deltaY ) } ]
  #1
  set oX  [ expr { $X1 + 7.0 * $deltaX } ]
  set oY  [ expr { $Y1 + 3.0 * $deltaY } ]
  set nPlanet [ lindex $listPlanet 0 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  #2
  set nPlanet [ lindex $listPlanet 1 ]
  set fill_color    [ getPlanetFillColor $nPlanet   ]
  set outline_color [ getPlanetBorderColor $nPlanet ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  9.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  3.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  #3
  set nPlanet [ lindex $listPlanet 2 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 11.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  3.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color  listPoints_loc $pen_size $outline_color
  
  #4
  set nPlanet [ lindex $listPlanet 3 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 7.0 * $deltaX } ]
  set oY  [ expr { $Y1 + 6.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #5
  set nPlanet [ lindex $listPlanet 4 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  9.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  6.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
  
  #6
  set nPlanet [ lindex $listPlanet 5 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]
  
  set oX  [ expr { $X1 +  11.0 * $deltaX } ]
  set oY  [ expr { $Y1 +   6.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #7
  set nPlanet [ lindex $listPlanet 6 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  1.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #8
  set nPlanet [ lindex $listPlanet 7 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  3.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #9
  set nPlanet [ lindex $listPlanet 8 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  5.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #10
  set nPlanet [ lindex $listPlanet 9 ]
  set fill_color    [ getPlanetFillColor $nPlanet   $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  7.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #11
  set nPlanet [ lindex $listPlanet 10 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  9.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #12
  set nPlanet [ lindex $listPlanet 11 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  11.0 * $deltaX } ]
  set oY  [ expr { $Y1 +   9.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

} elseif { $nElem == 13 } {
  set deltaX [ expr { ($X2 - $X1)/12.0 } ]
  set deltaY [ expr { ($Y2 - $Y1)/12.0 } ]
  set R   [ expr { min ( $deltaX, $deltaY ) } ]
  #1
  set oX  [ expr { $X1 + 7.0 * $deltaX } ]
  set oY  [ expr { $Y1 + 3.0 * $deltaY } ]
  set nPlanet [ lindex $listPlanet 0 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  #2
  set nPlanet [ lindex $listPlanet 1 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  9.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  3.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  #3
  set nPlanet [ lindex $listPlanet 2 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 11.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  3.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
  
  #4
  set nPlanet [ lindex $listPlanet 3 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 7.0 * $deltaX } ]
  set oY  [ expr { $Y1 + 6.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #5
  set nPlanet [ lindex $listPlanet 4 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  9.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  6.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
  
  #6
  set nPlanet [ lindex $listPlanet 5 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign  ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]
  
  set oX  [ expr { $X1 +  11.0 * $deltaX } ]
  set oY  [ expr { $Y1 +   6.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #7
  set nPlanet [ lindex $listPlanet 6 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  1.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #8
  set nPlanet [ lindex $listPlanet 7 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  3.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #9
  set nPlanet [ lindex $listPlanet 8 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  5.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #10
  set nPlanet [ lindex $listPlanet 9 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  7.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc  $pen_size $outline_color

  #11
  set nPlanet [ lindex $listPlanet 10 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  9.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #12
  set nPlanet [ lindex $listPlanet 11 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  11.0 * $deltaX } ]
  set oY  [ expr { $Y1 +   9.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #13
  set nPlanet [ lindex $listPlanet 12 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +   1.5 * $deltaX } ]
  set oY  [ expr { $Y1 +   11.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc  $pen_size $outline_color

} elseif { $nElem >= 14 } {
  set deltaX [ expr { ($X2 - $X1)/12.0 } ]
  set deltaY [ expr { ($Y2 - $Y1)/12.0 } ]
  set R   [ expr { min ( $deltaX, $deltaY ) } ]
  #1
  set oX  [ expr { $X1 + 7.0 * $deltaX } ]
  set oY  [ expr { $Y1 + 3.0 * $deltaY } ]
  set nPlanet [ lindex $listPlanet 0 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  #2
  set nPlanet [ lindex $listPlanet 1 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  9.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  3.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
 
  #3
  set nPlanet [ lindex $listPlanet 2 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 11.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  3.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
  
  #4
  set nPlanet [ lindex $listPlanet 3 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 + 7.0 * $deltaX } ]
  set oY  [ expr { $Y1 + 6.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #5
  set nPlanet [ lindex $listPlanet 4 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  9.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  6.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
  
  #6
  set nPlanet [ lindex $listPlanet 5 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]
  
  set oX  [ expr { $X1 +  11.0 * $deltaX } ]
  set oY  [ expr { $Y1 +   6.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #7
  set nPlanet [ lindex $listPlanet 6 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  1.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #8
  set nPlanet [ lindex $listPlanet 7 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  3.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #9
  set nPlanet [ lindex $listPlanet 8 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  5.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #10
  set nPlanet [ lindex $listPlanet 9 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  7.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #11
  set nPlanet [ lindex $listPlanet 10 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  9.0 * $deltaX } ]
  set oY  [ expr { $Y1 +  9.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #12
  set nPlanet [ lindex $listPlanet 11 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +  11.0 * $deltaX } ]
  set oY  [ expr { $Y1 +   9.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #13
  set nPlanet [ lindex $listPlanet 12 ]
  set fill_color    [ getPlanetFillColor $nPlanet  $nSign ]
  set outline_color [ getPlanetBorderColor $nPlanet $nSign ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +    1.5 * $deltaX } ]
  set oY  [ expr { $Y1 +   11.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  #14
  set nPlanet [ lindex $listPlanet 13 ]
  set fill_color    [ getPlanetFillColor $nPlanet   ]
  set outline_color [ getPlanetBorderColor $nPlanet ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +    3.5 * $deltaX } ]
  set oY  [ expr { $Y1 +   11.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color

  for {set tmp 14} { $tmp < $nElem} {incr tmp}{

  set nPlanet [ lindex $listPlanet $tmp ]
  set fill_color    [ getPlanetFillColor $nPlanet   ]
  set outline_color [ getPlanetBorderColor $nPlanet ]
  set pen_size      [ getPlanetPenSize $nPlanet ]

  set oX  [ expr { $X1 +    (3.5 + 2*($tmp - 13))* $deltaX } ]
  set oY  [ expr { $Y1 +   11.0 * $deltaY } ]
  
  drawPlanet $c $oX $oY $R $nPlanet $fill_color listPoints_loc $pen_size $outline_color
   
  }
        
 } else {
 }

}

proc drawHoroscope { c  w h pen_size border_color background_color rasi_nav} {

global signs planets

$c create rectangle 0 0 $w $h -outline $background_color -fill $background_color	-width 0

set  colorSigns [ getColorSigns ]
set listSignsPlanets {}

foreach { s } $signs {
 
  set listSign {}
  
  foreach { p } $planets {
 
   if { [ SignOfPlanet $p $rasi_nav -fix ] == $s } {
        
    lappend listSign $p

   }
  }
 
  lappend listSignsPlanets $listSign
 
 }

set listPoints {}


drawZodiac $c $pen_size $pen_size [expr $w -$pen_size] [expr $h -$pen_size] $colorSigns $listSignsPlanets listPoints $pen_size $border_color 


set pen_size 2
set pen_color black

for { set i 0 } { $i < [ llength $listPoints ] } { incr i } {
 
 set varPointi [ lindex $listPoints $i ]
 set pi [lindex $varPointi 0]
 set xi [lindex $varPointi 1]
 set yi [lindex $varPointi 2]
 set ri [lindex $varPointi 3]
 
 for { set j 0 } { $j < [ llength $listPoints ] } { incr j } {
 
  set varPointj [ lindex $listPoints $j ]
  set pj [lindex $varPointj 0]
  set xj [lindex $varPointj 1]
  set yj [lindex $varPointj 2]
  set rj [lindex $varPointj 3]
 
    
    if { [ HAspectedBy $pi $pj $rasi_nav]  &&  [okAspect $pi $pj] } {
   
      set k [ expr { $rj / sqrt (    ($xi-$xj) * ($xi-$xj) + ($yi-$yj)*($yi-$yj) ) } ]
     	set xk [expr { $xj + $k *($xi-$xj) } ]
    	set yk [expr { $yj + $k *($yi-$yj) } ]

    	set l  [expr { $rj / sqrt (    ($xi-$xj) * ($xi-$xj) + ($yi-$yj)*($yi-$yj) ) } ]
      set xl [expr { $xj - $k *($xj-$xi) } ]
      set yl [expr { $yj - $k *($yj-$yi) } ]
      
       	
     	drawArrow $c $xk $yk $xl $yl $pen_size $pen_color
     
    }

    if { [ HAspectedBy $pj $pi $rasi_nav] &&  [okAspect $pj $pi] } {

     set k  [expr { $ri / sqrt (    ($xi-$xj) * ($xi-$xj) + ($yi-$yj)*($yi-$yj) ) } ]
     set xk [expr { $xi + $k *($xj-$xi) } ]
     set yk [expr { $yi + $k *($yj-$yi) } ]
      
     set l  [expr { $rj / sqrt (    ($xi-$xj) * ($xi-$xj) + ($yi-$yj)*($yi-$yj) ) } ]
     set xl [expr { $xj - $k *($xj-$xi) } ]
     set yl [expr { $yj - $k *($yj-$yi) } ]
      
     drawArrow $c $xk $yk $xl $yl $pen_size $pen_color
     
    }
   
   }
 }

}

proc drawZodiac {c left top right bottom colorSigns listSignsPlanets listPoints {pen_size 1} { outline_color black } { fill_color white } } {
 
 set deltaX  [ expr { ($right - $left)/4.0 } ]
 set deltaY  [ expr { ($bottom - $top)/4.0 } ]
 set margin [ expr { max($deltaX/6.0, $deltaY/6.0) } ]
 set R  [ expr { min($deltaX/6.0, $deltaY/6.0) } ]
 #font create fontW -family Wingdings -size [ expr { int(-2*$R) } ] -weight bold  
 font configure fontW  -size [ expr { int(-2*$R) } ] -weight bold  
  
 global aries      
 global taurus     
 global gemini     
 global cancer     
 global leo        
 global virgo      
 global libra      
 global scorpio    
 global sagittarius
 global capricornus
 global aquarius   
 global pisces     

upvar 1 $listPoints listPoints_loc


#Draw Signs
 
# Pisces
 set X1 $left
 set Y1 $top
 set X2 [ expr { $X1  + $deltaX } ]
 set Y2 [ expr { $Y1  + $deltaY } ]
 set sign_color [ lindex $colorSigns $pisces ]
 $c create rectangle $X1 $Y1 $X2 $Y2 -outline $outline_color -fill $sign_color -width $pen_size		
  
 set coX [ expr { $X1 + $margin } ]
 set coY [ expr { $Y1 + $margin } ]
 set cR  [ expr { min($deltaX/6.0, $deltaY/6.0) } ]
 drawSign $c $coX $coY 12 fontW $outline_color

drawListPlanets $c $X1 $Y1 $X2 $Y2 [lindex $listSignsPlanets $pisces] $pisces listPoints_loc
 

# Aries
 set X1 [ expr { $X1  + $deltaX } ]
 set X2 [ expr { $X1  + $deltaX } ]
 set sign_color [ lindex $colorSigns $aries ]
 
 $c create rectangle $X1 $Y1 $X2 $Y2 -outline $outline_color -fill $sign_color -width $pen_size

 set coX [ expr { $X1 + $margin } ]
 set coY [ expr { $Y1 + $margin } ]
 set cR  [ expr { min($deltaX/6.0, $deltaY/6.0) } ]
 drawSign $c $coX $coY 1 fontW $outline_color

 drawListPlanets $c $X1 $Y1 $X2 $Y2 [lindex $listSignsPlanets $aries] $aries listPoints_loc

# Taurus
 set X1 [ expr { $X1  + $deltaX } ]
 set X2 [ expr { $X1  + $deltaX } ]
 set sign_color [ lindex $colorSigns $taurus ]
 
 $c create rectangle $X1 $Y1 $X2 $Y2 -outline $outline_color -fill $sign_color -width $pen_size

 set coX [ expr { $X1 + $margin } ]
 set coY [ expr { $Y1 + $margin } ]
 set cR  [ expr { min($deltaX/6.0, $deltaY/6.0) } ]
 drawSign $c $coX $coY 2 fontW $outline_color
 
 drawListPlanets $c $X1 $Y1 $X2 $Y2 [lindex $listSignsPlanets $taurus] $taurus listPoints_loc

# Gemini
 set X1 [ expr { $X1  + $deltaX } ]
 set X2 [ expr { $X1  + $deltaX } ]
 set sign_color [ lindex $colorSigns $gemini ]
 
 $c create rectangle $X1 $Y1 $X2 $Y2 -outline $outline_color -fill $sign_color -width $pen_size	
 
 set coX [ expr { $X1 + $margin } ]
 set coY [ expr { $Y1 + $margin } ]
 set cR  [ expr { min($deltaX/6.0, $deltaY/6.0) } ]
 drawSign $c $coX $coY 3 fontW $outline_color

 drawListPlanets $c $X1 $Y1 $X2 $Y2 [lindex $listSignsPlanets $gemini] $gemini listPoints_loc
 
 # Cancer
 set Y1 $Y2
 set Y2 [ expr { $Y1  + $deltaY } ]
 set sign_color [ lindex $colorSigns $cancer ]

 $c create rectangle $X1 $Y1 $X2 $Y2 -outline $outline_color -fill $sign_color -width $pen_size

 set coX [ expr { $X1 + $margin } ]
 set coY [ expr { $Y1 + $margin } ]
 set cR  [ expr { min($deltaX/6.0, $deltaY/6.0) } ]
 drawSign $c $coX $coY 4 fontW $outline_color

 drawListPlanets $c $X1 $Y1 $X2 $Y2 [lindex $listSignsPlanets $cancer] $cancer listPoints_loc 

 # Leo 
 set Y1 $Y2
 set Y2 [ expr { $Y1  + $deltaY } ]
 set sign_color [ lindex $colorSigns $leo ]

 $c create rectangle $X1 $Y1 $X2 $Y2 -outline $outline_color -fill $sign_color -width $pen_size

 set coX [ expr { $X1 + $margin } ]
 set coY [ expr { $Y1 + $margin } ]
 set cR  [ expr { min($deltaX/6.0, $deltaY/6.0) } ]
 drawSign $c $coX $coY 5 fontW $outline_color
 
 drawListPlanets $c $X1 $Y1 $X2 $Y2 [lindex $listSignsPlanets $leo] $leo listPoints_loc
 

 # Virgo
 set Y1 $Y2
 set Y2 [ expr { $Y1  + $deltaY } ]
 set sign_color [ lindex $colorSigns $virgo ]

 $c create rectangle $X1 $Y1 $X2 $Y2 -outline $outline_color -fill $sign_color -width $pen_size

 set coX [ expr { $X1 + $margin } ]
 set coY [ expr { $Y1 + $margin } ]
 set cR  [ expr { min($deltaX/6.0, $deltaY/6.0) } ]
 drawSign $c $coX $coY 6 fontW $outline_color
 
 drawListPlanets $c $X1 $Y1 $X2 $Y2 [lindex $listSignsPlanets $virgo] $virgo listPoints_loc

# Libra
 set X1 [ expr { $X1  - $deltaX } ]
 set X2 [ expr { $X1  + $deltaX } ]
 set sign_color [ lindex $colorSigns $libra ] 

 $c create rectangle $X1 $Y1 $X2 $Y2 -outline $outline_color -fill $sign_color -width $pen_size	

 set coX [ expr { $X1 + $margin } ]
 set coY [ expr { $Y1 + $margin } ]
 set cR  [ expr { min($deltaX/6.0, $deltaY/6.0) } ]
 drawSign $c $coX $coY 7 fontW $outline_color
 
 drawListPlanets $c $X1 $Y1 $X2 $Y2 [lindex $listSignsPlanets $libra] $libra listPoints_loc

# Scorpio
 set X1 [ expr { $X1  - $deltaX } ]
 set X2 [ expr { $X1  + $deltaX } ]
 set sign_color [ lindex $colorSigns $scorpio ]

 $c create rectangle $X1 $Y1 $X2 $Y2 -outline $outline_color -fill $sign_color -width $pen_size	

 set coX [ expr { $X1 + $margin } ]
 set coY [ expr { $Y1 + $margin } ]
 set cR  [ expr { min($deltaX/6.0, $deltaY/6.0) } ]
 drawSign $c $coX $coY 8 fontW $outline_color
 
 drawListPlanets $c $X1 $Y1 $X2 $Y2 [lindex $listSignsPlanets $scorpio] $scorpio listPoints_loc

# Sagittarius
 set X1 [ expr { $X1  - $deltaX } ]
 set X2 [ expr { $X1  + $deltaX } ]
 set sign_color [ lindex $colorSigns $sagittarius ]

 $c create rectangle $X1 $Y1 $X2 $Y2 -outline $outline_color -fill $sign_color -width $pen_size	

 set coX [ expr { $X1 + $margin } ]
 set coY [ expr { $Y1 + $margin } ]
 set cR  [ expr { min($deltaX/6.0, $deltaY/6.0) } ]
 drawSign $c $coX $coY 9 fontW $outline_color
 
 drawListPlanets $c $X1 $Y1 $X2 $Y2 [lindex $listSignsPlanets $sagittarius] $sagittarius listPoints_loc

# Capricorn
set Y1 [ expr { $Y1  - $deltaY } ]
set Y2 [ expr { $Y1  + $deltaY } ]
set sign_color [ lindex $colorSigns $capricornus ]

$c create rectangle $X1 $Y1 $X2 $Y2 -outline $outline_color -fill $sign_color -width $pen_size	

set coX [ expr { $X1 + $margin } ]
set coY [ expr { $Y1 + $margin } ]
set cR  [ expr { min($deltaX/6.0, $deltaY/6.0) } ]
drawSign $c $coX $coY 10 fontW $outline_color

drawListPlanets $c $X1 $Y1 $X2 $Y2 [lindex $listSignsPlanets $capricornus] $capricornus listPoints_loc

# Aquarius

set Y1 [ expr { $Y1  - $deltaY } ]
set Y2 [ expr { $Y1  + $deltaY } ]
set sign_color [ lindex $colorSigns $aquarius ]

$c create rectangle $X1 $Y1 $X2 $Y2 -outline $outline_color -fill $sign_color -width $pen_size	

set coX [ expr { $X1 + $margin } ]
set coY [ expr { $Y1 + $margin } ]
set cR  [ expr { min($deltaX/6.0, $deltaY/6.0) } ]
drawSign $c $coX $coY 11 fontW $outline_color

drawListPlanets $c $X1 $Y1 $X2 $Y2 [lindex $listSignsPlanets $aquarius] $aquarius listPoints_loc


}

############################################################

set background_color [ GetBackgroundColor ]

set pen_size 5
set width  600
set height 600
set border_color [ GetPenColor ]

set mainW .
wm title $mainW "Hindu Horoscope"

# Open horoscope 
if {![SetCurrentHoroscope]} {
 return
} 

label  .titre1 -text "[Name] [FirstName]"  -background $background_color
label  .titre2 -text "[BirthDateHourUT] UT"   -background $background_color
label  .titre3 -text "[BirthCity] [BirthCountry]" -background $background_color

label  .pied_page1 -text Rasi -background $background_color
label  .pied_page2 -text Navamsa -background $background_color 

canvas .c_rasi -width $width -height $height -bg $background_color 
set   c_rasi .c_rasi
bind .c_rasi <Configure> {pConfigure $c_rasi %w %h -rasi}

canvas .c_nav -width $width -height $height -bg $background_color 
set   c_nav .c_nav
bind .c_nav <Configure> {pConfigure $c_nav %w %h -nav}

grid  .titre1 -column 0 -row 0 -columnspan 2 -sticky nsew
grid  .titre2 -column 0 -row 1 -columnspan 2 -sticky nsew
grid  .titre3 -column 0 -row 2 -columnspan 2 -sticky nsew

grid  .c_rasi   -column 0 -row 3 -sticky nsew
grid  .c_nav    -column 1 -row 3 -sticky nsew

grid  .pied_page1  -column 0 -row 4 -sticky nsew
grid  .pied_page2  -column 1 -row 4 -sticky nsew


grid columnconfigure . 0 -weight 1
grid columnconfigure . 1 -weight 1

# 4 lines below are commented to say that Name/Birth Date and Label Rasi and Navamsa are not sizable, only the drawing are resizable
 
#grid rowconfigure . 0 -weight 5
#grid rowconfigure . 1 -weight 5
#grid rowconfigure . 2 -weight 5 
grid rowconfigure . 3 -weight 1
#grid rowconfigure . 4 -weight 5

drawHoroscope $c_rasi $width $height $pen_size $border_color $background_color -rasi
drawHoroscope $c_nav $width $height $pen_size $border_color $background_color -nav
 
 
#############################################################

proc pConfigure {c w h card} {
	global pen_size border_color background_color
		
	drawHoroscope $c $w $h $pen_size $border_color $background_color $card
	
}


