###############################################################################
# Author  : Patrick Régnier
# Created : 5/1997
# Last modified: 02/2022 
# This is the default Tcl script file for the astrologic interpretation
# of a horoscope. You can modifie it if you know Tcl langage.
# Commands added to Tcl for astrological purpose are listed in file 
# commands_part1.tcl and commands_part2.tcl 
# Any suggestions and good ideas welcome 
# (see online help for how to contact me).
# For others langages than French, please translate inter.txt to your own
# language. inter.txt must be in text (UTF8 without BOM) mode.
################################################################################

################################################################################
# Conventions
#
# Numbers of signs   are 0 to 11 Aries to Pisces
#
# Numbers of planets in Proastro are 0 to 14 :
# 0  = Sun,     1 = Moon,      2 = Mercury,
# 3  = Venus,   4 = Mars,      5 = Jupiter
# 6  = Saturn   7 = Ascendant, 8 = Mid-heaven,
# 9  = Rahu (Ascendant node of moon), 10 = Kethu (Descendant node of moon)
# 11 = Uranus, 12 = Neptune,   13 = Pluto, 14 = Fortune
#
#####################################################################################
# Dans le fichier inter_fr1.txt, les textes correspondent aux maisons comptées
# selon le sens CONTRAIRE aux signes. 
# Le texte planète en maison 4  correspond au texte planète au MC (qui est la maison 9 si vous comptez les maisons dans le même sens que les signes)
# Le texte planète en maison 10 correspond au texte planète au FC (qui est la maison 3 si vous comptez les maisons dans le même sens que les signes)
# Pour ceux que ne travaillent que "maisons signes dans le même sens"
# Une solution peut être de créer un nouveau fichier d'interprétation inter_fr10.txt, copie de inter_fr1.txt, par 
# exemple et permuter les textes planètes en maison 4 et 10 et de faire pointer ce script ou
# une copie sur le fichier inter_fr10.txt avec l'instruction 
# set idfi 10
# il est possible d'ajouter des entrée dans le menu Interprétation/Personnalisé
# en éditant le fichier menu_tcl_tk.ini dans le répertoire privé de Proastro. 
# Note: La méthode maisons dans les sens contraire des signes est préconisée par Jacques Dorsan dans le livre
# "Le véritable sens de maisons astrologiques" aux édtions du rocher.
######################################################################################
# In the inter_us1.txt file, the texts correspond to the houses counted
# in the OPPOSITE directions of the signs.
# The planet text in the 4th house corresponds to the planet text in the MH (which is the 9th house if you count the houses in the same direction as the signs)
# The planet text in the 10th house corresponds to the planet text in the IC (which is the 3rd house if you count the houses in the same direction as the signs)
# For those who only work "houses with signs in the same direction"
# A solution can be to create a new interpretation file inter_fr10.txt, copied from inter_us1.txt, for
# example and permute the texts planets in house 4 and 10 and to point this script or
# a copy on the inter_us10.txt file with the instruction
# set idfi 10
# it is possible to add entries in the Interpretation/Custom menu
# by editing the menu_tcl_tk.ini file in the Proastro private directory.
# Note: The method houses in the opposite direction of the signs is recommended by Jacques Dorsan in the book (french)
# "Le véritable sens de maisons astrologiques" aux édtions du rocher (Monaco).
####################################################################################

#--- give the number of Astro text paragraph 
#--- for an aspect between two planets 

proc nAspectTxt { a b quality origin } {
if { $quality > 0 } { set dec 0 } else {set dec 1}
if {$a > $b} {
 set i $b
 set j $a } else {
 set i $a
set j $b
}
 
 set k [expr $origin + 28*$i - $i*($i-1) + 2*($j -$i -1)  + $dec]
 return $k
}

# get de 2 first letters of a planet, in EN language
# used for stars interpretation 
proc getPlanetENPrefix { a } {

 switch $a {
 
 0  {return "SU"}
 1  {return "MO"}
 2  {return "ME"}
 3  {return "VE"}
 4  {return "MA"}
 5  {return "JU"}
 6  {return "SA"}
 7  {return "AS"}
 8  {return "MH"}
 9  {return "RA"}
 10 {return "KE"}
 11 {return "UR"}
 12 {return "NE"}
 13 {return "PL"}
 14 {return "FO"}
 } 

}

# for idstr in inter_*.txt files, not depending on the language
proc getPlanetENName { nplanet } {

switch $nplanet {
 0  {return "Sun"}
 1  {return "Moon"}
 2  {return "Mercury"}
 3  {return "Venus"}
 4  {return "Mars"}
 5  {return "Jupiter"}
 6  {return "Saturn"}
 7  {return "As"}
 8  {return "MH"}
 9  {return "Rahu"}
 10 {return "Ketu"}
 11 {return "Uranus"}
 12 {return "Neptune"}
 13 {return "Pluto"}
 14 {return "Fortune"}
 } 

}

# same for french or english, latin names
proc getSignName { nsign } {
 return [NameOfSign $nsign]
}

# will return for example
# Sun in Aries well disposed
# or
# Sun in Aries ill disposed
proc getPlanetSignIdstr { nplanet nsign pquality } {

 set str_quality "well"
 
 if { $pquality < 0 } {
  set str_quality "ill"
 }
 
 set str_planet [getPlanetENName $nplanet]
 set str_sign   [getSignName $nsign] 
 
 return "$str_planet in $str_sign $str_quality disposed"

}

# will return for example
# Venus in house 1 well disposed
# nhouse is from 1
proc getPlanetHouseIdstr { nplanet nhouse pquality } {

 set str_quality "well"
 
 if { $pquality < 0 } {
  set str_quality "ill"
 }

 set str_planet [getPlanetENName $nplanet]
  
 return "$str_planet in house $nhouse $str_quality disposed"

}

# will return for example
# Moon in good aspect with MH
# Moon in good aspect with Saturn
# Moon in good aspect with Jupiter
proc getPlanetsAspectIdstr { np_aspected np_aspecting aquality } {

 set str_quality "good"
 
 if { $aquality < 0 } {
  set str_quality "bad"
 }

 set str_planet_aspected  [getPlanetENName $np_aspected]
 set str_planet_aspecting [getPlanetENName $np_aspecting]

 # for occidental astrology Sun good aspect with Moon is the same as Moon good aspect with Sun
 # but the interpretation file has only the first text, no the second so make the smallest planet the first one 

 if { $np_aspected < $np_aspecting } {
   return "$str_planet_aspected in $str_quality aspect with $str_planet_aspecting"
 } else {
   return "$str_planet_aspecting in $str_quality aspect with $str_planet_aspected"
 }

}
proc conjunction {np1 np2 rasi_nav options_signs} {
  
  if { $np1 == $np2 } {return 0}
   
  set s1 [SignOfPlanet $np1 $rasi_nav $options_signs]
  set s2 [SignOfPlanet $np2 $rasi_nav $options_signs]
 
  if { $s1==$s2 } { return 1}

  return 0

}

# will return for example
# Mercury in house 3 ill disposed
# Mercury in house 4 well disposed
proc getPlanetHouseIdstr { nplanet nhouse pquality } {
 
  set str_planet [getPlanetENName $nplanet]
  set str_quality "well"
  
  if {$pquality < 0} {
    set str_quality "ill"
  } 

  return "$str_planet in house $nhouse $str_quality disposed" 

}

#--- Get quality of planets

proc FindQualityOfPanets {} {
 
 # 0 = neutral, 1 = Good, -1 = Bad
 # QualityOfPlanet is a global array
 
 global QualityOfPlanet
 set ncrosschecking 7
 
 for {set i 0} { $i < 15 } {incr i} {
   
  set QualityOfPlanet($i) [HQualityOfPlanet $i $ncrosschecking]   
 }

 # force quality of fortune to benefic
 set QualityOfPlanet(14) 1

}

#Occidental quality of aspect, conjunction good sextil good, square bad, trigone good, opposition bad
# good : 1 bad -1 : neutral: 0
proc OccidentalQualityOfAspect { value_aspect } { 
  
  set value_aspect_int [expr {round($value_aspect)}]
  
  switch $value_aspect_int {
     0  {return 1 }
    60  {return 1 }
	90  {return -1 }
	120 {return 1 }
	180 {return -1 }
    default {return 0}
    }
}

################################################################################
# Initializations
################################################################################

# Set debug on or off
# Warning: Must be the first instruction!
# if Debug is on, index file for inter.txt will be overwritten
# each time this script is being executed, witch will slow down performance

SetPRDebug -off

# Rebuild index 
# this allow you to change interpretation files and check this script output without need of restarting Proastro
# usefull if you are testing changes in interpretation files
RebuildInterpTxtIndex

# Open the horoscope for interpretation
if {![SetCurrentHoroscope]} {
 PutTxt "interpretation aborted"
return
}

# Get Astro Type

if { [GetAstroType]!=0} {
 # Movable Astrology
 set options_signs   "-mov"
} else {
# Fix Astrology
 set options_signs   "-fix"
}

# house direction
if { [isSHSD]!= 0} {
 # house and sign same direction
 set options_houses  "-shsd"
} else {
# house and sign opposite direction
 set options_houses  "-shod"
}

# cusp of house in center of house 
if { [isHouseCuspCenter]!= 0} {
 set options_houses_center  "-center"
} else {
set options_houses_center  ""
} 

set nplanet_AS 7
set nplanet_MH 8

# id of interpretation file
set idfi 1

set origin_planets           13
set origin_aspects          373
set origin_houses           583
set origin_stars            956

# declare a global array for quality of planets
for {set i 0} {$i < 15} {incr i} {
set QualityOfPlanet($i) 0
}

# Find Quality of planets
FindQualityOfPanets

################################################################################
# Warning
################################################################################

# Name of the horoscope
if { [GetLang]=="FR" } {
 PutTxt "Interprétation de la carte du ciel de [Name] [FirstName]"
} else {
 PutTxt "Interpretation of horoscope for [Name] [FirstName]"
}

PutTxt "[BirthDateHourUT] [BirthCity] [BirthCountry]"
#

PutTxt "--------------------------------------------------------------------------------"
PutAstroTxt "Warning" $idfi  -fromidstr
PutTxt "--------------------------------------------------------------------------------"
PutTxt ""

################################################################################
# Count the number of planets (Sun to Saturn)
# above or underneath horizon.
# I don't care about Uranus, Neptune, Pluto because they are invisible.
# I may be wrong... 
################################################################################

if { [GetLang]=="FR" } {
   PutTxt "*** Quelques particularités de la carte du ciel ***"
   PutTxt ""
 } else {
   PutTxt "*** Some particularities about this horoscope ***"
   PutTxt ""
 }

set pa    0 ; # above
set pu    0 ; # underneath

foreach {i} {0 1 2 3 4 5 6 } {
 set diff [expr [LongOfPlanet $i $options_signs] - [LongOfPlanet $nplanet_AS  $options_signs] ]
 # must be in 0° - 360°
 set diff [ToZ360 $diff]
 if {$diff > 180} {
	incr pa 1
  } else {
	  incr pu 1
	 }
}

# more than 5 above horizon
if {$pa >= 5} {
  PutAstroTxt "All planets above horizon" $idfi  -fromidstr
}

# more than 5 are underneath horizon
if {$pu >= 5} {
  PutAstroTxt "All planets under horizon" $idfi  -fromidstr
}

################################################################################
# Count planets in the same side of ascendant or in opposite side
# Sun..Saturn plus Uranus, Neptun and Pluto
################################################################################

set pa    0 ; # ascendant
set po    0 ; # descendant

foreach {i} {0 1 2 3 4 5 6 11 12 13} {
 set diff [expr [LongOfPlanet $i $options_signs] - [LongOfPlanet $nplanet_MH $options_signs]]
 # must be in 0° - 360°
 set diff [ToZ360 $diff]
 if {$diff > 180} {
	incr po 1
  } else {
	  incr pa 1
	 }
}

# more than 7 in ascendant side
if {$pa >= 7} {
  PutAstroTxt "All planets at As side" $idfi  -fromidstr
}

# more than 7 are descendant side
if {$po >= 7} {
  PutAstroTxt "All planets at Ds side" $idfi  -fromidstr
}

################################################################################
# Planets in Fire, Earth, Air and Water signs
################################################################################

set pf 0 ; # fire
set pe 0 ; # earth
set pa 0 ; # air
set pw 0 ; # water

foreach {i} {0 1 2 3 4 5 6 11 12 13} {
 set nsign [SignOfPlanet $i $options_signs -rasi]
 set nsign [expr $nsign %4]  ; # remainder of division by 4
 switch $nsign {
  0 {incr pf}
  1 {incr pe}
  2 {incr pa}
  3 {incr pw}
 }
}

# most planets in fire signs
if {$pf >= 5} {
  PutAstroTxt "All planets in fire signs" $idfi  -fromidstr
}

# most planets in earth signs
if {$pe >= 5} {
  PutAstroTxt "All planets in earth signs" $idfi  -fromidstr
}

# most planets in air signs
if {$pa >= 5} {
  PutAstroTxt "All planets in air signs" $idfi  -fromidstr
}

# most planets in water signs
if {$pw >= 5} {
  PutAstroTxt "All planets in water signs" $idfi  -fromidstr
}

################################################################################
# Planets in Moveable, Fix, Common signs
################################################################################

set pm 0 ; # moveable
set pf 0 ; # fix
set pc 0 ; # common

foreach {i} {0 1 2 3 4 5 6 11 12 13} {
 set nsign [SignOfPlanet $i $options_signs -rasi]
 set nsign [expr $nsign %3]  ; # remainder of division by 3
 switch $nsign {
  0 {incr pm}
  1 {incr pf}
  2 {incr pc}
 }
}

# most planets in moveable signs
if {$pm >= 7} {
  PutAstroTxt "All planets in movable signs" $idfi  -fromidstr
}

# most planets in fix signs
if {$pf >= 7} {
  PutAstroTxt "All planets in fixed signs" $idfi  -fromidstr
}

# most planets in common signs
if {$pc >= 7} {
  PutAstroTxt "All planets in common sign" $idfi  -fromidstr
}

PutTxt ""

#--- free some variables ---
unset pa
unset pu
unset po
unset pf
unset pe
unset pw
unset pm
unset pc

################################################################################
# Moon is the more important planet in Fix (or Hindu) astrology, so
# let us give the interpretation for moon in sign.
################################################################################

if { [GetLang]=="FR" } {
   PutTxt "*** Positions et aspects de la Lune ***"
   PutTxt ""
 } else {
   PutTxt "*** Positions and aspects of Moon ***"
   PutTxt ""
 }

# Moon in sign
set nplanet 1 
set nsign  [SignOfPlanet $nplanet $options_signs -rasi] 
set npquality $QualityOfPlanet($nplanet)
set idstr    [getPlanetSignIdstr $nplanet $nsign $npquality]
PutAstroTxt $idstr $idfi  -fromidstr

PutTxt ""

# Moon in House
set nhouse [HouseOfPlanet $nplanet $options_houses -rasi $options_houses_center]
set idstr    [getPlanetHouseIdstr $nplanet $nhouse $npquality]
PutAstroTxt $idstr $idfi  -fromidstr

PutTxt ""

################################################################################
# Aspect or conjunction with the moon and the others planets
################################################################################

# hindus aspects
if { [GetLang]=="FR" } {
   PutTxt "+++ Aspects hindous Lune +++"
   PutTxt ""
 } else {
   PutTxt "+++ Hindu aspects Moon +++"
   PutTxt ""
 }

set np_aspected  1
foreach {i} {0 2 3 4 5 6 7 8 9 10 11 12 13 14} {
 set np_aspecting $i
 set aquality [HQualityOfAspect $np_aspected $np_aspecting $nplanet_AS]
  
 if {$aquality < 99} {
   set idstr [getPlanetsAspectIdstr $np_aspected $np_aspecting $aquality ]
   PutAstroTxt $idstr $idfi  -fromidstr
   PutTxt "" 
  } else {
   # check if planet and moon are in conjunction, ie in same sign
   # if yes assume that quality of aspect is good
   set rasi_nav "-rasi"
   set is_conjunction [ conjunction $np_aspected $np_aspecting $rasi_nav $options_signs ]    
   if { $is_conjunction == 1} {
     set aquality 1
     set idstr [getPlanetsAspectIdstr $np_aspected $np_aspecting $aquality ]
     PutAstroTxt $idstr $idfi  -fromidstr
	 PutTxt "" 
	 # Todo when several planets are in the same sign as Moon, just choose the nearest from Moon ?
   }
  }
}

PutTxt "+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
PutTxt ""

# occidental aspects with Moon
if { [GetLang]=="FR" } {
   PutTxt "+++ Aspects occidentaux Lune +++"
   PutTxt ""
 } else {
   PutTxt "+++ Occidental aspects Moon +++"
   PutTxt ""
 }

set np_aspected  1
foreach {i} {0 2 3 4 5 6 7 8 9 10 11 12 13 14} {
 set np_aspecting $i
 set list [GetAspectPP $np_aspected $np_aspecting]
  
 if { [ llength $list] != 0 } {

  set name_aspect    [lindex $list 0]
  set value_aspect   [lindex $list 1]
  set orb_aspect     [lindex $list 2]
  set angle_aspect   [lindex $list 3]
  set angle_aspect   [expr {double(round(100*$angle_aspect))/100}]
  set quality_aspect [OccidentalQualityOfAspect $value_aspect]   
  set idstr [getPlanetsAspectIdstr $np_aspected $np_aspecting $quality_aspect ]
  PutTxt  "[NameOfPlanet $np_aspected] $name_aspect [NameOfPlanet $np_aspecting] ($angle_aspect)"
  PutAstroTxt $idstr $idfi  -fromidstr
  PutTxt ""  
 }
}

PutTxt "+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
PutTxt ""

################################################################################
# Ascendant and Lord of Ascendant
################################################################################

# As in sign
set nplanet 7 
set nsign  [SignOfPlanet $nplanet $options_signs -rasi] 
set npquality $QualityOfPlanet($nplanet)
set idstr    [getPlanetSignIdstr $nplanet $nsign $npquality]
PutAstroTxt $idstr $idfi  -fromidstr
PutTxt ""  

# Aspects (Hindus) with As, skipping As 7, MH 8, Rahu 9, Ketu 10, Fortune 14
if { [GetLang]=="FR" } {
   PutTxt "+++ Aspects hindous sur l'As +++"
   PutTxt ""
 } else {
   PutTxt "+++ Hindu aspects on As +++"
   PutTxt ""
 }

set np_aspected  7
foreach {i} {0 1 2 3 4 5 6 11 12 13 } {
 set np_aspecting $i
 set aquality [HQualityOfAspect $np_aspected $np_aspecting $nplanet_AS]
  
 if {$aquality < 99} {
   set idstr [getPlanetsAspectIdstr $np_aspected $np_aspecting $aquality ]
   PutAstroTxt $idstr $idfi  -fromidstr
   PutTxt "" 
  } else {
   # check if planet and moon are in conjunction, ie in same sign
   # if yes assume that quality of aspect is good
   set rasi_nav "-rasi"
   set is_conjunction [ conjunction $np_aspected $np_aspecting $rasi_nav $options_signs ]    
   if { $is_conjunction == 1} {
     set aquality 1
     set idstr [getPlanetsAspectIdstr $np_aspected $np_aspecting $aquality ]
     PutAstroTxt $idstr $idfi  -fromidstr
	 PutTxt "" 
	 # Todo when several planets are in the same sign as AS, just choose the nearest from Moon ?
   }
  }
}

PutTxt "+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
PutTxt ""

# Aspects (occidentals) with As without As, MH, Fortune 
if { [GetLang]=="FR" } {
   PutTxt "+++ Aspects occidentaux sur l'As +++"
   PutTxt ""
 } else {
   PutTxt "+++ Occidental aspects sur l'As +++"
   PutTxt ""
 }
 
set np_aspected  7
foreach {i} {0 1 2 3 4 5 6   9 10 11 12 13 } {
 set np_aspecting $i
 set list [GetAspectPP $np_aspected $np_aspecting]
  
 if { [ llength $list] != 0 } {

  set name_aspect    [lindex $list 0]
  set value_aspect   [lindex $list 1]
  set orb_aspect     [lindex $list 2]
  set angle_aspect   [lindex $list 3]
  set angle_aspect   [expr {double(round(100*$angle_aspect))/100}]
  set quality_aspect [OccidentalQualityOfAspect $value_aspect]   
  set idstr [getPlanetsAspectIdstr $np_aspected $np_aspecting $quality_aspect ]
  PutTxt  "[NameOfPlanet $np_aspected] $name_aspect [NameOfPlanet $np_aspecting] ($angle_aspect)"
  PutAstroTxt $idstr $idfi  -fromidstr
  PutTxt ""  
 }
}

PutTxt "+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
PutTxt ""

###############################################
# Lord of first house (Ascendant) in sign
# if the lord is moon, nothing to do 
###############################################

set nplanet [LordOfHouse 1 $options_signs $options_houses -rasi]

 if { [GetLang]=="FR" } {
   PutTxt "*** Le maître de l'ascendant est [NameOfPlanet $nplanet] ***"
   PutTxt ""
 } else {
   PutTxt "*** Lord of As is [NameOfPlanet $nplanet] ***"
   PutTxt ""
 }

if {$nplanet != 1} {
 set npquality $QualityOfPlanet($nplanet)
 set nsign  [SignOfPlanet $nplanet $options_signs -rasi]
 set idstr  [getPlanetSignIdstr $nplanet $nsign $npquality]
 PutAstroTxt $idstr $idfi  -fromidstr
 PutTxt ""  
}

# Lord of first house in house
set nplanet [LordOfHouse 1 $options_houses  $options_signs -rasi]
set pquality $QualityOfPlanet($nplanet)
set nhouse  [HouseOfPlanet $nplanet $options_houses $options_houses_center -rasi]
set idstr [getPlanetHouseIdstr $nplanet $nhouse $pquality]

PutAstroTxt $idstr $idfi  -fromidstr
PutTxt "" 

# Aspect or conjunction with Lord of ascendant (Hindu)
if { [GetLang]=="FR" } {
   PutTxt "+++ Aspects hindous sur le maître de l'As +++"
   PutTxt ""
 } else {
   PutTxt "+++ Hindu aspects on As lord +++"
   PutTxt ""
 }
set np_aspected   [LordOfHouse 1 $options_houses  $options_signs -rasi]
foreach {i} {0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 } {
 set np_aspecting $i
 set aquality [HQualityOfAspect $np_aspected $np_aspecting $nplanet_AS]

 if { $np_aspecting != $np_aspected } {
   if {$aquality < 99} {
    set idstr [getPlanetsAspectIdstr $np_aspected $np_aspecting $aquality ]
    PutAstroTxt $idstr $idfi  -fromidstr
    PutTxt "" 
   } else {
    # check if planet and lord of As are in conjunction, ie in same sign
    # if yes assume that quality of aspect is good
    set rasi_nav "-rasi"
    set is_conjunction [ conjunction $np_aspected $np_aspecting $rasi_nav $options_signs ]    
     if { $is_conjunction == 1} {
       set aquality 1
       set idstr [getPlanetsAspectIdstr $np_aspected $np_aspecting $aquality ]
       PutAstroTxt $idstr $idfi  -fromidstr
	   PutTxt "" 
	   # Todo when several planets are in the same sign as lord of As, just choose the nearest from Moon ?
     }
   }
 }
}

PutTxt "+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
PutTxt ""

# Aspect or conjunction with Lord of ascendant (Occidental)
if { [GetLang]=="FR" } {
   PutTxt "+++ Aspects occidentaux sur le maître de l'As +++"
   PutTxt ""
 } else {
   PutTxt "+++ Occidental aspects on As lord +++"
   PutTxt ""
 }

set np_aspected  [LordOfHouse 1 $options_houses  $options_signs -rasi]
foreach {i} {0 1 2 3 4 5 6 7 8 9 10 11 12 13 14} {
 if {$i != $np_aspected} {
  set np_aspecting $i
  set list [GetAspectPP $np_aspected $np_aspecting]
  
  if { [ llength $list] != 0 } {
   set name_aspect    [lindex $list 0]
   set value_aspect   [lindex $list 1]
   set orb_aspect     [lindex $list 2]
   set angle_aspect   [lindex $list 3]
   set angle_aspect   [expr {double(round(100*$angle_aspect))/100}]
   set quality_aspect [OccidentalQualityOfAspect $value_aspect]   
   set idstr [getPlanetsAspectIdstr $np_aspected $np_aspecting $quality_aspect ]
   PutTxt  "[NameOfPlanet $np_aspected] $name_aspect [NameOfPlanet $np_aspecting] ($angle_aspect)"
   PutAstroTxt $idstr $idfi  -fromidstr
   PutTxt ""  
  }
 }
}

PutTxt "+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
PutTxt ""

################################################################################
# Planets in sign and house. if planet is lord of house 1, nothing to do.
################################################################################

if { [GetLang]=="FR" } {
 PutTxt ""
 PutTxt "*************************************************************************************************"
 PutTxt "*** Boucle pour chaque planète                                                                ***"
 PutTxt "*** Chaque planète doit être interprétée en fonction de son interaction avec l'Ascendant,     ***"
 PutTxt "*** le maître de l'Ascendant, la Lune et peut-être le maître du signe lunaire.                ***"
 PutTxt "*** Une planète doit synthétiser sa position en signe, en maison, les aspects avec les autres ***"
 PutTxt "*** planètes et pour plus de détails les maisons dont elle est maîtresse.                     ***"
 PutTxt "*************************************************************************************************"
 PutTxt ""
} else {
 PutTxt ""
 PutTxt "**********************************************************************************************"
 PutTxt "*** Loop for each planet                                                                   ***"
 PutTxt "*** Each planet must be interpreted according to its interaction with the Ascendant,       ***"
 PutTxt "*** the lord of the Ascendant, the Moon and perhaps the lord of the moon sign.             ***"
 PutTxt "*** A planet must synthesize its position in sign, house, aspects with other               ***"
 PutTxt "*** planets and for more details of the houses it master.                                  ***"
 PutTxt "**********************************************************************************************"
 PutTxt ""
}

set np_lord_As  [LordOfHouse 1 $options_houses  $options_signs -rasi]
set nplanet_AS  7

# Main loop for all aspected planet except Moon , As Lord, As
foreach {np_aspected} {0 2 3 4 5 6 8 9 10 11 12 13 14} {

  if {$np_aspected == $np_lord_As} {
   continue
  }
   
  # Planet aspected in sign
  set nsign  [SignOfPlanet $np_aspected $options_signs -rasi] 
  set npquality $QualityOfPlanet($np_aspected)
  set idstr    [getPlanetSignIdstr $np_aspected $nsign $npquality]
  PutAstroTxt $idstr $idfi  -fromidstr
  PutTxt ""

  # Planet aspected in House
  if { $np_aspected != 7  &&  $np_aspected != 8 } {
   set nhouse [HouseOfPlanet $np_aspected $options_houses -rasi $options_houses_center]
   set idstr  [getPlanetHouseIdstr $np_aspected $nhouse $npquality]
   PutAstroTxt $idstr $idfi  -fromidstr
   PutTxt ""
  }
 
  # Hindus aspects of planet 
  if { [GetLang]=="FR" } {
    PutTxt "+++ Aspects hindous pour planète aspectée [NameOfPlanet $np_aspected] +++"
    PutTxt ""
  } else {
    PutTxt "+++ Hindu aspects for aspected planet [NameOfPlanet $np_aspected] +++"
    PutTxt ""
  }

  # Aspecting except Moon, As, MH, Rahu, Ketu, Fortune
  foreach {np_aspecting} {0 2 3 4 5 6 11 12 13} {
	 if {$np_aspecting == $np_lord_As || $np_aspecting == $np_aspected} {
      continue
     }

     # to avoid redondant output text
	 if { $np_aspecting > $np_aspected } {
	  continue
	 }

     set aquality [HQualityOfAspect $np_aspected $np_aspecting $nplanet_AS]
  
     if {$aquality < 99} {
      set idstr [getPlanetsAspectIdstr $np_aspected $np_aspecting $aquality ]
      PutAstroTxt $idstr $idfi  -fromidstr
      PutTxt "" 
     } else {
      # check if planets are in conjunction, ie in same sign
      # if yes assume that quality of aspect is good
      set rasi_nav "-rasi"
      set is_conjunction [ conjunction $np_aspected $np_aspecting $rasi_nav $options_signs ]    
      if { $is_conjunction == 1} {
         set aquality 1
         set idstr [getPlanetsAspectIdstr $np_aspected $np_aspecting $aquality ]
         PutAstroTxt $idstr $idfi  -fromidstr
	     PutTxt "" 
	     # Todo when several planets are in the same sign, just choose the narrow conjunction  ?
      }
     }
  }
  
  PutTxt "+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
  PutTxt ""

  # occidental aspects with planets
   if { [GetLang]=="FR" } {
     PutTxt "+++ Aspects occidentaux pour la planète [NameOfPlanet $np_aspected] +++"
     PutTxt ""
   } else {
     PutTxt "+++ Occidental aspects for planet [NameOfPlanet $np_aspected] +++"
     PutTxt ""
   }
   
   foreach {np_aspecting} {0 2 3 4 5 6 8 9 10 11 12 13 14} {
     
 	 if {$np_aspecting == $np_lord_As || $np_aspecting == $np_aspected } {
       continue
      }
   
     set list [GetAspectPP $np_aspected $np_aspecting]
   
     if { [ llength $list] != 0 } {

      set name_aspect    [lindex $list 0]
      set value_aspect   [lindex $list 1]
      set orb_aspect     [lindex $list 2]
      set angle_aspect   [lindex $list 3]
      set angle_aspect   [expr {double(round(100*$angle_aspect))/100}]
      set quality_aspect [OccidentalQualityOfAspect $value_aspect]   
      set idstr [getPlanetsAspectIdstr $np_aspected $np_aspecting $quality_aspect ]
      PutTxt  "[NameOfPlanet $np_aspected] $name_aspect [NameOfPlanet $np_aspecting] ($angle_aspect)"
      PutAstroTxt $idstr $idfi  -fromidstr
      PutTxt ""  
     }
   }
   
   PutTxt "+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
   PutTxt ""
   
}

#################################################################################
#
# Planets or As or M.H. in conjunction with fixed stars
# Orb is 1° before or after the star
#
#################################################################################
set orb 1.0

if { [GetLang]=="FR" } {
 PutTxt "Conjonctions des planètes avec les étoiles, orbe $orb ° "
} else {
 PutTxt "Conjonctions between stars and planets, orb is $orb ° "
}

PutTxt "--------------------------------------------------------------------------------"

set n_stars [GetStarsCount]

for { set p 0} {$p < 15} {incr p} {
 for {set s 0} {$s < $n_stars} { incr s} {
  set idstar [IdStarConjunctionWithPlanet $p $s $orb]
 
  if { $idstar > 0 } {
   set idstr [getPlanetENPrefix $p]
   set idstr "$idstr$idstar"
   
   
   if { [GetLang]=="FR" } {
       PutTxt "[NameOfPlanet $p] conjonction avec [NameOfStar [IdStar2Num $idstar]] ( [CommentOfStar [IdStar2Num $idstar]] )"
      } else {
       PutTxt "[NameOfPlanet $p] conjunction with [NameOfStar [IdStar2Num $idstar]] ( [CommentOfStar [IdStar2Num $idstar]] )"
     }
     
   #PutAstroTxt $idstr $idfi  -idstr -fromidstr
   PutAstroTxt $idstr $idfi  -fromidstr
   PutTxt ""

  }
 
 }
}

PutTxt "--------------------------------------------------------------------------------"
PutTxt ""

if { [GetLang]=="FR" } {
 PutTxt "**************************************** Fin de fichier ****************************************"
} else {
 PutTxt "**************************************** End of file    ****************************************"
}
PutTxt ""
