###############################################################################
# Author  : Patrick Régnier
# Created : 5/1997
# Last modified: 02/2016 
# This is the default Tcl script file for the astrologic interpretation
# of a sidereal solar return horoscope. You can modifie it if you know Tcl langage.
# Commands added to Tcl for astrological purpose are listed in file 
# commands_part1.tcl and commands_part2.tcl 
# For others langages than French, please translate inter3.txt to your own
# language. inter3.txt must be in text(UTF8 without BOM) mode.
################################################################################

#####################################################################################
# Dans le fichier inter_fr1.txt, les textes correspondent aux maisons comptées
# selon le sens CONTRAIRE aux signes. 
# Le texte planète en maison 4  correspond au texte planète au MC
# Le texte planète en maison 10 correspond au texte planète au FC
# et ce, même si la maison 4 "signes maisons sens contraire" correspond à la maison 9 "signes maisons même sens"
# ou si la maison 10 "signes maisons sens contraire" correspond à la maison 3 "signes maisons même sens".
# D'où l'inversion ci-dessous, pour que l'erreur soit plus juste ;)
# Pour ceux que ne travaillent que "maisons signes dans le même sens"
# Une solution peut-être de créer un nouveau fichier d'interprétation inter_fr10.txt, copie de inter_fr1.txt, par 
# exemple et permuter les textes planètes en maison 4 et 10 et de faire pointer ce script ou
# une copie sur le fichier inter_fr10.txt avec l'instruction 
# set idfi 10
# il est possible d'ajouter des entrée dans le menu Interprétation/Personnalisé
# en éditant le fichier menu_tcl_tk.ini dans le répertoire privé de Proastro. 
######################################################################################
# In the file inter_us1.txt The text are for houses in the OPPOSITE direction of signs. 
# The text planet in house 4 matches planet in MH
# The text planet in house 10 matches planet in IC, 
# even if the house 4 "signs houses opposite direction" is the 9th "signs houses same direction"
# or if the house 10 "signs houses opposite direction" corresponds to the house 3 "signs houses same direction". 
# Hence the inversion below. One solution may be to create a new interpretation file inter_us10.txt 
# and swap planets texts house 4 to 10 and to point this script or a copy of it to the inter_fr10.txt file with instruction 
# set idfi 10
# It is possible to add entry in the Interpretation/Custom menu by editing the menu_tcl_tk.ini file in the Proastro
# private directory.
#####################################################################################

# id of the interpretation txt file
set idfi 3

set sun      0
set moon     1
set mercury  2
set venus    3
set mars     4
set jupiter  5
set saturn   6
set asc      7
set mh       8
set rahu     9
set ketu     10
set uranus   11
set neptune  12
set pluto    13
set fortune  14

proc getPlanetENName { nplanet } {

switch $nplanet {
 0  {return "Sun"}
 1  {return "Moon"}
 2  {return "Mercury"}
 3  {return "Venus"}
 4  {return "Mars"}
 5  {return "Jupiter"}
 6  {return "Saturn"}
 7  {return "As"}
 8  {return "MH"}
 9  {return "Rahu"}
 10 {return "Ketu"}
 11 {return "Uranus"}
 12 {return "Neptune"}
 13 {return "Pluto"}
 14 {return "Fortune"}
 } 
}

SetPRDebug -off

# Rebuild index 
# this allow you to change interpretation files and check this script output without need of restarting Proastro
# usefull if you are testing changes in interpretation files
  RebuildInterpTxtIndex

 if { [GetLang]=="FR" } {
  set txt_title_bh "Choisir la carte du ciel natale SVP "
  set horoscope_of "Carte du ciel de"
  set ssr "Révolution solaire"
  set zfix "Zodiaque sidéral" 
  set mshod "Signes et maisons dans le même contraire"
  set ssr_house_in_natal_house "*** Maisons de la révolution solaire dans les maisons natales ***"
  set ssr_house_in_sign "*** Maisons de la révolution solaire en signes ***"
  set ssr_planets_in_rs_houses "*** Planètes révolution solaire en maisons révolution solaire ***"
 } else {
  set txt_title_bh "Choose the birth horoscope please"       
  set horoscope_of "Horoscope of"
  set ssr "Sidereal solar return"
  set zfix "Sidereal zodiac" 
  set mshsd "Signs and houses same direction"
  set mshod "Signs and houses opposite direction"
  set ssr_house_in_natal_house "*** SSR houses in natal houses ***"
  set ssr_house_in_sign "*** SSR houses in signs ***"
  set ssr_planets_in_rs_houses "*** SSR planets in ssr houses ***"
 }

 if { [GetLang]=="FR" } {
  set txt_title_bh_ssr "Choisir la carte du ciel de la RS SVP "
 } else {
  set txt_title_bh_ssr "Choose the SSR horoscope please"       
 }

# Name
if {![SetCurrentHoroscope -title $txt_title_bh]} {
 return
}

PutTxt "$horoscope_of : [Name] [FirstName]"

if {![SetCurrentHoroscope -title $txt_title_bh_ssr]} {
 return
}

PutTxt "$ssr : [Name] [FirstName]"
PutTxt "" 

# Force astro Type to fix
set options_signs   "-fix"
PutTxt $zfix

# Force house direction to sign house opposite direction
set options_houses  "-shod"
PutTxt $mshod

# house is cuspide not center
set options_houses_center  ""

# Warning
PutTxt "" 
PutAstroTxt "Warning" $idfi  -fromidstr
PutTxt "" 

#Longitude of house in SR horoscope
SetCurrentHoroscope -nh 2
for {set i 1} { $i <= 12 } {incr i} {
 set ssr_long_h($i)  [LongOfHouse  $i  $options_signs $options_houses -rasi]
 #PutTxt "Debug SSR $i=$ssr_long_h($i)"
}

# back to birth horoscope
SetCurrentHoroscope -nh 1

#Longitude of house in natal horoscope
for {set i 1} { $i <= 12 } {incr i} {
 set natal_long_h($i)  [LongOfHouse  $i  $options_signs $options_houses -rasi]
 #PutTxt "Debug Natal $i=$natal_long_h($i)"
}

SetCurrentHoroscope -nh 1

for {set i 1} { $i <= 12 } {incr i} {
 set ssr_h($i)  [HouseOfPoint  $ssr_long_h($i) $options_signs $options_houses $options_houses_center -rasi]
 set ssr_s($i)  [SignOfPoint   $ssr_long_h($i) ]
 
 #PutTxt "Debug SSR $i=[NameOfSign $ssr_s($i)]" 
 #PutTxt "Debug SSR $i=$ssr_h($i)" 
}

# ssr house in natal houses 
PutTxt $ssr_house_in_natal_house
PutTxt ""

# H1 SSR in H1 (natal)
# to 
# H12 SSR in H12 (natal)

for {set i 1} { $i <= 12 } {incr i} {
 
 set rs_house     $i 
 set natal_house  $ssr_h($i) 
 #PutTxt "Debug i=$i natal_house=$natal_house rs_house=$rs_house"
 
 set idstr "H$rs_house SSR in H$natal_house"
 
 PutAstroTxt $idstr $idfi  -fromidstr
 PutTxt ""
}

# ssr house in sign
PutTxt $ssr_house_in_sign
PutTxt ""

# H1 SSR in ARIES
# to
# H12 SSR in PISCES

for {set i 1} { $i <= 12 } {incr i} {

 set sign_name [NameOfSign $ssr_s($i)]
 set sign_name [string toupper $sign_name]
 set idstr "H$i SSR in $sign_name"

 PutAstroTxt $idstr $idfi  -fromidstr
 PutTxt ""
}

#planet position in houses, ssr
# for example 
# SUN SSR in H1 SSR
PutTxt $ssr_planets_in_rs_houses
PutTxt ""
#

SetCurrentHoroscope -nh 2
set pl "$sun $moon $mercury $venus $mars $jupiter $saturn $uranus $neptune $pluto"
foreach {i} $pl {
 
 set planet_name [getPlanetENName $i]
 set planet_name [string toupper $planet_name]
 set h [HouseOfPlanet $i $options_houses $options_houses_center -rasi]
  
 #PutTxt "Debug i=$i h=$h"
 set idstr "$planet_name SSR in H$h SSR"

 PutAstroTxt $idstr $idfi  -fromidstr
 PutTxt ""
  
}


